==> qtjambi-quick-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiQuick/QQuickItemGrabResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtCore/QVariant>
#include <QtGui/qimage.h>
#include <QtCore/qurl.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/QList>
#include <QtCore/qobject.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qtimer.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qvariant.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qthread.h>
#include <QtCore/qproperty.h>
#include <QtCore/qbindingstorage.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QQuickItemGrabResult_0(){
    static int result = QMetaMethod::fromSignal(&QQuickItemGrabResult::ready).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QQuickItemGrabResult::image()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItemGrabResult_image_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QQuickItemGrabResult *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItemGrabResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickItemGrabResult::image()const", __qt_this)
        QImage __qt_return_value = __qt_this->image();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQuickItemGrabResult::saveToFile(QString)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItemGrabResult_saveToFile_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring fileName0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQuickItemGrabResult *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItemGrabResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickItemGrabResult::saveToFile(QString)const", __qt_this)
        QString  __qt_fileName0 = qtjambi_cast<QString>(__jni_env, fileName0);
        __java_return_value = __qt_this->saveToFile(__qt_fileName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQuickItemGrabResult::saveToFile(QUrl)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItemGrabResult_saveToFile_1native_1cref_1QUrl_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID fileName0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQuickItemGrabResult *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItemGrabResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickItemGrabResult::saveToFile(QUrl)const", __qt_this)
        const QUrl& __qt_fileName0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(fileName0);
        __java_return_value = __qt_this->saveToFile(__qt_fileName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQuickItemGrabResult::url()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItemGrabResult_url_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QQuickItemGrabResult *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItemGrabResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickItemGrabResult::url()const", __qt_this)
        QUrl __qt_return_value = __qt_this->url();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QUrl_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType);
bool nativeToJavaConverter_QUrl_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool);

bool javaToNativeConverter_QUrl_cref(JNIEnv* env, QtJambiScope* scope, jvalue in, void* &out, jValueType) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    if(out){
        *reinterpret_cast<QUrl*>(out) = qtjambi_cast<const QUrl& >(env, in.l);
    }else{
        out = const_cast<QUrl*>(&qtjambi_cast<const QUrl& >(env, in.l));
    }
    return true;
}

bool nativeToJavaConverter_QUrl_cref(JNIEnv* env, QtJambiScope* scope, const void* in, jvalue& out, bool) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    out.l = qtjambi_cast<jobject>(env, *reinterpret_cast<QUrl const*>(in));
    return true;
}


void initialize_meta_info_QQuickItemGrabResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QQuickItemGrabResult>("QQuickItemGrabResult", "io/qt/quick/QQuickItemGrabResult");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QQuickItemGrabResult::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "ready", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QQuickItemGrabResult_0)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QQuickItemGrabResult_0()){ // ready()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QQuickItemGrabResult::staticMetaObject.indexOfMethod("saveToFile(QString)const")){
                    infos << ParameterInfo(QMetaType::Bool);
                    infos << ParameterInfo(QMetaType::QString);
                    return true;
                }
                if(methodIndex==QQuickItemGrabResult::staticMetaObject.indexOfMethod("saveToFile(QUrl)const")){
                    infos << ParameterInfo(QMetaType::Bool);
                    infos << ParameterInfo(
                                // const QUrl&
                                method.parameterType(0),
                                "io/qt/core/QUrl",
                                &nativeToJavaConverter_QUrl_cref,
                                &javaToNativeConverter_QUrl_cref);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-linux-x64-6.7.2.jar: sources/QtJambiQuick/QQuickItemGrabResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtGui/qimage.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QQuickItemGrabResult_0(){
    static int result = QMetaMethod::fromSignal(&QQuickItemGrabResult::ready).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QQuickItemGrabResult::image()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItemGrabResult_image_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QQuickItemGrabResult *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItemGrabResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickItemGrabResult::image()const", __this_nativeId)
        QImage __qt_return_value = __qt_this->image();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQuickItemGrabResult::saveToFile(QString)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItemGrabResult_saveToFile_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring fileName0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQuickItemGrabResult *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItemGrabResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickItemGrabResult::saveToFile(QString)const", __this_nativeId)
        QString __qt_fileName0 = qtjambi_cast<QString>(__jni_env, fileName0);
        __java_return_value = __qt_this->saveToFile(__qt_fileName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQuickItemGrabResult::saveToFile(QUrl)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItemGrabResult_saveToFile_1native_1cref_1QUrl_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID fileName0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQuickItemGrabResult *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItemGrabResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickItemGrabResult::saveToFile(QUrl)const", __this_nativeId)
        const QUrl& __qt_fileName0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(fileName0);
        __java_return_value = __qt_this->saveToFile(__qt_fileName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQuickItemGrabResult::url()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QQuickItemGrabResult_url_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QQuickItemGrabResult *__qt_this = QtJambiAPI::objectFromNativeId<QQuickItemGrabResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuickItemGrabResult::url()const", __this_nativeId)
        QUrl __qt_return_value = __qt_this->url();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QUrl_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType);
bool nativeToJavaConverter_QUrl_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool);

bool javaToNativeConverter_QUrl_cref(JNIEnv* env, QtJambiScope* scope, jvalue in, void* &out, jValueType) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    if(out){
        *reinterpret_cast<QUrl*>(out) = qtjambi_cast<const QUrl&>(env, in.l);
    }else{
        out = const_cast<QUrl*>(&qtjambi_cast<const QUrl&>(env, in.l));
    }
    return true;
}

bool nativeToJavaConverter_QUrl_cref(JNIEnv* env, QtJambiScope* scope, const void* in, jvalue& out, bool) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    out.l = qtjambi_cast<jobject>(env, *reinterpret_cast<QUrl const*>(in));
    return true;
}


void initialize_meta_info_QQuickItemGrabResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QQuickItemGrabResult>("QQuickItemGrabResult", "io/qt/quick/QQuickItemGrabResult");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QQuickItemGrabResult::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "ready", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QQuickItemGrabResult_0)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QQuickItemGrabResult_0()){ // ready()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QQuickItemGrabResult::staticMetaObject.indexOfMethod("saveToFile(QString)const")){
                    infos << ParameterInfo(QMetaType::Bool);
                    infos << ParameterInfo(QMetaType::QString);
                    return true;
                }
                if(methodIndex==QQuickItemGrabResult::staticMetaObject.indexOfMethod("saveToFile(QUrl)const")){
                    infos << ParameterInfo(QMetaType::Bool);
                    infos << ParameterInfo(
                                // const QUrl&
                                method.parameterType(0),
                                "io/qt/core/QUrl",
                                &nativeToJavaConverter_QUrl_cref,
                                &javaToNativeConverter_QUrl_cref);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
